Changelog
========================================================


0.0.5 (2021-01-22)
-------------------

- Several fixes in documentation.


0.0.4 (2021-01-22)
-------------------

- Fixed in documentation.

- Added examples for `query_params` in the doc examples.

- Updated directory name from `mopinion_client` to `mopinion`.

- Implemented About in Docs and Readme.

0.0.3 (2021-01-20)
-------------------

- Fixed typing in method `get_token`. Return `bytes` instead of `str`.

0.0.2 (2021-01-20)
-------------------

- Fixed in documentation.

- Removed travis ci. Integrated GitHub Actions.

- Added coverage into GitHub actions.

0.0.1 (2021-01-20)
-------------------

- Initial project structure.

- Client implementation.

- Test suite.

- Request examples.

